library ieee;
use ieee.std_logic_1164.all;

library impulse;
use impulse.fsl_if.all;

library fsl_filt_v1_00_a;
use fsl_filt_v1_00_a.all;


entity fsl_filt is
  generic (
    C_FAMILY           : string                    := "virtex2"  );
  port (
    -- fsl0 ports
    FSL_Clk : in std_ulogic;
    FSL_Rst : in std_ulogic;
    FSL0_S_Clk : out std_ulogic;
    FSL0_S_Exists : in std_ulogic;
    FSL0_S_Data : in std_ulogic_vector (31 downto 0);
    FSL0_S_Control : in std_ulogic;
    FSL0_S_Read : out std_ulogic;
    -- fsl1 ports
    FSL1_M_Full : in std_ulogic;
    FSL1_M_Clk : out std_ulogic;
    FSL1_M_Data : out std_ulogic_vector (31 downto 0);
    FSL1_M_Control : out std_ulogic;
    FSL1_M_Write : out std_ulogic;
    co_clk : in std_logic
    );
end fsl_filt;

architecture impl of fsl_filt is
  component filt is
    port (
    reset : in std_ulogic;
    sclk : in std_ulogic;
    clk : in std_ulogic;
    p_cpu_proc_output_stream_en : in std_ulogic;
    p_cpu_proc_output_stream_eos : in std_ulogic;
    p_cpu_proc_output_stream_data : in std_ulogic_vector (31 downto 0);
    p_cpu_proc_output_stream_rdy : out std_ulogic;
    p_cpu_proc_input_stream_en : in std_ulogic;
    p_cpu_proc_input_stream_data : out std_ulogic_vector (31 downto 0);
    p_cpu_proc_input_stream_eos : out std_ulogic;
    p_cpu_proc_input_stream_rdy : out std_ulogic
    );
  end component;

  signal p_cpu_proc_output_stream_rdy : std_ulogic;
  signal p_cpu_proc_output_stream_en : std_ulogic;
  signal p_cpu_proc_output_stream_eos : std_ulogic;
  signal p_cpu_proc_output_stream_idata : std_ulogic_vector (31 downto 0);
  signal p_cpu_proc_input_stream_rdy : std_ulogic;
  signal p_cpu_proc_input_stream_en : std_ulogic;
  signal p_cpu_proc_input_stream_eos : std_ulogic;
  signal p_cpu_proc_input_stream_idata : std_ulogic_vector (31 downto 0);


  -- fsl signals
  -- end fsl signals
begin
  FSL0_S_Clk <= FSL_Clk;
  p_cpu_proc_output_stream_if: fsl_to_stream
    generic map (
      datawidth => 32
    )
    port map (
      FSL_Rst, FSL_Clk,
      FSL0_S_Exists,
      FSL0_S_Data,
      FSL0_S_Control,
      FSL0_S_Read,
      stream_en => p_cpu_proc_output_stream_en,
      stream_rdy => p_cpu_proc_output_stream_rdy,
      stream_eos => p_cpu_proc_output_stream_eos,
      stream_data => p_cpu_proc_output_stream_idata
    );

  FSL1_M_Clk <= FSL_Clk;
  p_cpu_proc_input_stream_if: stream_to_fsl
    generic map (
      datawidth => 32
    )
    port map (
      FSL_Rst, FSL_Clk,
      FSL1_M_Full,
      FSL1_M_Write,
      FSL1_M_Control,
      FSL1_M_Data,
      stream_en => p_cpu_proc_input_stream_en,
      stream_rdy => p_cpu_proc_input_stream_rdy,
      stream_eos => p_cpu_proc_input_stream_eos,
      stream_data => p_cpu_proc_input_stream_idata
    );

  filt_0: filt
    port map (
      FSL_Rst,
      FSL_Clk,
      co_clk,
      p_cpu_proc_output_stream_en,
      p_cpu_proc_output_stream_eos,
      p_cpu_proc_output_stream_idata,
      p_cpu_proc_output_stream_rdy,
      p_cpu_proc_input_stream_en,
      p_cpu_proc_input_stream_idata,
      p_cpu_proc_input_stream_eos,
      p_cpu_proc_input_stream_rdy);

end;

