--------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2002-2005 by Impulse Accelerated Technologies, Inc.    --
-- All rights reserved.                                                 --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- fsl_if.vhd: Xilinx FSL Input Stream Interface                        --
--                                                                      --
-- Change History
-- --------------
-- 10/13/2003 - Scott Thibault
--   File created.
--
--------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;

entity fsl_to_stream is
  generic (
    datawidth : positive := 8
  );
  port (
    reset, clk : in std_ulogic;
    fsl_exists : in std_ulogic;
    fsl_data : in std_ulogic_vector (31 downto 0);
    fsl_control : in std_ulogic;
    fsl_read : out std_ulogic;
    stream_en : out std_ulogic;
    stream_rdy : in std_ulogic;
    stream_eos : out std_ulogic;
    stream_data : out std_ulogic_vector (datawidth-1 downto 0)
  );
end fsl_to_stream;

architecture rtl of fsl_to_stream is
  signal fsl_read_s : std_logic;
begin
  fsl_read_s <= fsl_exists and stream_rdy;
  fsl_read <= fsl_read_s;

  -- Write to stream
  stream_en <= fsl_read_s;
  stream_eos <= fsl_control;
  stream_data <= fsl_data(datawidth-1 downto 0);
end rtl;

library ieee;
use ieee.std_logic_1164.all;

entity stream_to_fsl is
  generic (
    datawidth : positive := 8
  );
  port (
    reset, clk : in std_logic;
    fsl_full : in std_ulogic;
    fsl_write : out std_ulogic;
    fsl_control : out std_ulogic;
    fsl_data : out std_ulogic_vector (31 downto 0);
    stream_en : out std_ulogic;
    stream_rdy : in std_ulogic;
    stream_eos : in std_ulogic;
    stream_data : in std_ulogic_vector (datawidth-1 downto 0)
  );
end stream_to_fsl;

architecture rtl of stream_to_fsl is
  signal accept : std_ulogic;
  signal extended_data : std_ulogic_vector (31 downto 0);
begin
  accept <= stream_rdy and not fsl_full;
--  extended_data(31 downto datawidth) <= (others => '0');
  extended_data(datawidth - 1 downto 0) <= stream_data;

  fsl_write <= accept;
  fsl_control <= stream_eos;
  fsl_data <= extended_data;

  stream_en <= accept;
end rtl;

library ieee;
use ieee.std_logic_1164.all;

package fsl_if is

  component fsl_to_stream is
  generic (
    datawidth : positive := 8
  );
  port (
    reset, clk : in std_ulogic;
    fsl_exists : in std_ulogic;
    fsl_data : in std_ulogic_vector (31 downto 0);
    fsl_control : in std_ulogic;
    fsl_read : out std_ulogic;
    stream_en : out std_ulogic;
    stream_rdy : in std_ulogic;
    stream_eos : out std_ulogic;
    stream_data : out std_ulogic_vector (datawidth-1 downto 0)
  );
  end component;

  component stream_to_fsl is
  generic (
    datawidth : positive := 8
  );
  port (
    reset, clk : in std_logic;
    fsl_full : in std_ulogic;
    fsl_write : out std_ulogic;
    fsl_control : out std_ulogic;
    fsl_data : out std_ulogic_vector (31 downto 0);
    stream_en : out std_ulogic;
    stream_rdy : in std_ulogic;
    stream_eos : in std_ulogic;
    stream_data : in std_ulogic_vector (datawidth-1 downto 0)
  );
  end component;

end;
